This example show how to translate Flask-Admin into different language using customized version of the `Flask-Babel <https://github.com/mrjoes/flask-babelex>`

To run this example:

1. Clone the repository::

     git clone https://github.com/flask-admin/flask-admin.git
     cd flask-admin

2. Create and activate a virtual environment::

     virtualenv env
     source env/bin/activate

3. Install requirements::

     pip install -r 'examples/babel/requirements.txt'

4. Run the application::

     python examples/babel/app.py


